##  Step 1. Add Transformations and Impacts With Architecture and Road Map Planning
The way you plan and visualize your to-be architecture in SAP LeanIX is supported by the [Architecture and Road Map Planning](https://help.sap.com/docs/leanix/ea/sap-leanix-architecture-and-road-map-planning?locale=en-US&state=PRODUCTION&version=CLOUD "The SAP LeanIX Architecture and Road Map Planning enhances SAP LeanIX Application Portfolio Management by offering advanced features for seamless planning and execution of transformation initiatives in enterprise architecture management.") that you have already started to use in [phase 2 (by adding Milestones)](https://help.sap.com/docs/leanix/ea/erp-transformation-prepare?locale=en-US&state=PRODUCTION&version=CLOUD "Build high-level transformation scenarios and plan a detailed roadmap.").
By enriching your SAP LeanIX Inventory and adding two additional features, Transformations (accessible through a separate tab on the Initiative Fact Sheet) and Impacts (automatic classification by SAP LeanIX whenever you create a Transformation), you will be able to:
  * Compare different transformation scenarios.
  * Visualize future states of your application landscape through an enhanced Report view ( Explained in the next section).
  * Create enhanced roadmaps and track the ERP transformation program, as well as keep tabs on changes in your enterprise architecture resulting from the transformation.


Find a detailed explanation of how to create transformations here: [Transformations](https://help.sap.com/docs/leanix/ea/transformations?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to define and manage Transformations in the Initiative Fact Sheet.").
By adding Transformations and Impacts to your scenarios, you will be able to answer questions like:
  * What happens if you stay to an SAP standard vs. if you use another system (e.g., introduce SAP SuccessFactors vs. Bamboo HR)? The PACE layering assessment you conducted in Phase 1 also helps you here, as you can track your decisions against the target maturity of your business capabilities.
  * Stay clean core fit-to-standard or custom implementation -
    * What would support the business better (Functional Fit from a business perspective)?
  * Which decision would improve our business (on the Business Capability Maturity level)?


As all the to-be architecture data needs to be added manually, make sure to balance the level of detail vs. effort when creating Transformations and Impacts. Once you gain clarity and get stakeholder buy-in on certain Initiatives, you can go ahead and plan out Transformations in detail that you will execute in the later stages. You will learn about executing the Transformations in [Phase 4. (Realize, Deploy & Run)](https://help.sap.com/docs/leanix/ea/erp-transformation-realize-deploy-run?locale=en-US&state=PRODUCTION&version=CLOUD "Run transformations, measure, and monitor progress using SAP LeanIX. Achieve transparency, communicate developments, and reflect on architecture changes for a successful transformation journey.").
